@@ -1,6 +1,5 @@
 __all__ = [
     'HASH_COLUMN',
-    'BATCH_SIZE',
     'DEFAULT_STATUS',
     'QUOTA_SERVICE',
     'STATUS_FIELDS',
@@ -12,8 +11,6 @@ __all__ = [
 
 HASH_COLUMN = 'carto_geocode_hash'
 
-BATCH_SIZE = 200
-
 DEFAULT_STATUS = {'gc_status_rel': 'relevance'}
 
 QUOTA_SERVICE = 'hires_geocoder'
